# Weather Reporter

A Python package to get weather reports for a location.

## Usage

Following query on terminal will provide you the weather details of "dhaka" for next 7 days.

```
summer-days -q dhaka -d 7
```


